@@ -1,8 +1,8 @@
-import sys
-
 from easyprocess import EasyProcess
 
-from pyscreenshot.tempexport import extract_version, read_prog_img
+from pyscreenshot.plugins.backend import CBackend
+from pyscreenshot.tempexport import read_prog_img
+from pyscreenshot.util import extract_version, platform_is_osx
 
 PROGRAM = "import"
 # http://www.imagemagick.org/
@@ -12,20 +12,17 @@ class ImagemagickBackendError(Exception):
     pass
 
 
-class ImagemagickWrapper(object):
+class ImagemagickWrapper(CBackend):
     name = "imagemagick"
-    childprocess = True
+    is_subprocess = True
 
     def __init__(self):
-        if sys.platform == "darwin":
-            raise ImagemagickBackendError("osx not supported")  # TODO
-
-        p = EasyProcess([PROGRAM, "-version"])
-        p.enable_stdout_log = False
-        p.enable_stderr_log = False
-        p.call()
+        pass
 
     def grab(self, bbox=None):
+        if platform_is_osx():
+            raise ImagemagickBackendError("osx not supported")
+
         command = [PROGRAM, "-silent", "-window", "root"]
         if bbox:
             pbox = "{}x{}+{}+{}".format(
