@@ -1,11 +1,11 @@
 import logging
-import sys
 
 from PIL import Image
 
-PY2 = sys.version_info[0] == 2
+from pyscreenshot.plugins.backend import CBackend
+from pyscreenshot.util import py2
 
-if PY2:
+if py2():
     import StringIO
 
     BytesIO = StringIO.StringIO
@@ -19,31 +19,27 @@ log = logging.getLogger(__name__)
 
 # based on qt4 backend
 
+app = None
 
-class PySideGrabWindow(object):
+
+class PySideGrabWindow(CBackend):
     name = "pyside"
-    childprocess = False
-
-    app = None
 
     def __init__(self):
-        import PySide
+        pass
 
-        self.PySide = PySide
+    def grab_to_buffer(self, buff, file_type="png"):
         from PySide import QtGui
         from PySide import QtCore
 
-        self.QtGui = QtGui
-        self.QtCore = QtCore
+        QApplication = QtGui.QApplication
+        QBuffer = QtCore.QBuffer
+        QIODevice = QtCore.QIODevice
+        QPixmap = QtGui.QPixmap
 
-    def grab_to_buffer(self, buff, file_type="png"):
-        QApplication = self.PySide.QtGui.QApplication
-        QBuffer = self.PySide.QtCore.QBuffer
-        QIODevice = self.PySide.QtCore.QIODevice
-        QPixmap = self.PySide.QtGui.QPixmap
-
-        if not self.__class__.app:
-            self.__class__.app = QApplication([])
+        global app
+        if not app:
+            app = QApplication([])
         qbuffer = QBuffer()
         qbuffer.open(QIODevice.ReadWrite)
         QPixmap.grabWindow(QApplication.desktop().winId()).save(qbuffer, file_type)
@@ -61,4 +57,6 @@ class PySideGrabWindow(object):
         return im
 
     def backend_version(self):
-        return self.PySide.__version__
+        import PySide
+
+        return PySide.__version__
