@@ -1,11 +1,11 @@
 import logging
-import sys
 
 from PIL import Image
 
-PY2 = sys.version_info[0] == 2
+from pyscreenshot.plugins.backend import CBackend
+from pyscreenshot.util import py2
 
-if PY2:
+if py2():
     import StringIO
 
     BytesIO = StringIO.StringIO
@@ -21,31 +21,27 @@ log = logging.getLogger(__name__)
 # based on:
 # http://stackoverflow.com/questions/69645/take-a-screenshot-via-a-python-script-linux
 
+app = None
 
-class Qt4GrabWindow(object):
+
+class Qt4GrabWindow(CBackend):
     name = "pyqt"
-    childprocess = False
-
-    app = None
 
     def __init__(self):
-        import PyQt4
+        pass
 
-        self.PyQt4 = PyQt4
+    def grab_to_buffer(self, buff, file_type="png"):
         from PyQt4 import QtGui
         from PyQt4 import Qt
 
-        self.QtGui = QtGui
-        self.Qt = Qt
+        QApplication = QtGui.QApplication
+        QBuffer = Qt.QBuffer
+        QIODevice = Qt.QIODevice
+        QPixmap = QtGui.QPixmap
 
-    def grab_to_buffer(self, buff, file_type="png"):
-        QApplication = self.PyQt4.QtGui.QApplication
-        QBuffer = self.PyQt4.Qt.QBuffer
-        QIODevice = self.PyQt4.Qt.QIODevice
-        QPixmap = self.PyQt4.QtGui.QPixmap
-
-        if not self.__class__.app:
-            self.__class__.app = QApplication([])
+        global app
+        if not app:
+            app = QApplication([])
         qbuffer = QBuffer()
         qbuffer.open(QIODevice.ReadWrite)
         QPixmap.grabWindow(QApplication.desktop().winId()).save(qbuffer, file_type)
@@ -62,4 +58,6 @@ class Qt4GrabWindow(object):
         return im
 
     def backend_version(self):
-        return self.PyQt4.Qt.PYQT_VERSION_STR
+        from PyQt4 import Qt
+
+        return Qt.PYQT_VERSION_STR
