@@ -1,11 +1,11 @@
 import logging
-import sys
 
 from PIL import Image
 
-PY2 = sys.version_info[0] == 2
+from pyscreenshot.plugins.backend import CBackend
+from pyscreenshot.util import py2
 
-if PY2:
+if py2():
     import StringIO
 
     BytesIO = StringIO.StringIO
@@ -18,33 +18,28 @@ else:
 log = logging.getLogger(__name__)
 
 # based on qt5 backend
+app = None
 
 
-class QtPyGrabWindow(object):
+class QtPyGrabWindow(CBackend):
     name = "qtpy"
-    childprocess = False
 
     def __init__(self):
-        import qtpy
+        pass
 
-        self.qtpy = qtpy
+    def grab_to_buffer(self, buff, file_type="png"):
         from qtpy import QtGui
         from qtpy import QtCore
         from qtpy import QtWidgets
 
-        self.app = None
-        self.QtGui = QtGui
-        self.QtCore = QtCore
-        self.QtWidgets = QtWidgets
+        QApplication = QtWidgets.QApplication
+        QBuffer = QtCore.QBuffer
+        QIODevice = QtCore.QIODevice
+        QScreen = QtGui.QScreen
 
-    def grab_to_buffer(self, buff, file_type="png"):
-        QApplication = self.QtWidgets.QApplication
-        QBuffer = self.qtpy.QtCore.QBuffer
-        QIODevice = self.qtpy.QtCore.QIODevice
-        QScreen = self.qtpy.QtGui.QScreen
-
-        if not self.app:
-            self.app = QApplication([])
+        global app
+        if not app:
+            app = QApplication([])
         qbuffer = QBuffer()
         qbuffer.open(QIODevice.ReadWrite)
         QScreen.grabWindow(
@@ -63,4 +58,6 @@ class QtPyGrabWindow(object):
         return im
 
     def backend_version(self):
-        return self.qtpy.__version__
+        import qtpy
+
+        return qtpy.__version__
